const webpack = require('webpack');
const path = require('path');
const env = process.env.NODE_ENV ? process.env.NODE_ENV : 'production'
const sourcePath = path.join(__dirname, 'src');
const buildPath = path.join(__dirname, 'public', 'local', 'dist');

const MiniCssExtractPlugin = require('mini-css-extract-plugin'); // css uglify
const CssMinimizerPlugin = require("css-minimizer-webpack-plugin")
const TerserPlugin = require('terser-webpack-plugin'); // minifi ES6
const LiveReloadPlugin = require('webpack-livereload-plugin');

module.exports = {
  entry: path.join(sourcePath, 'scripts', 'app.js'),
  output: {
    path: buildPath,
    filename: 'bundle.js',
  },
  devtool: "source-map",
  optimization: {
    minimize: env == 'production',
    minimizer: [new TerserPlugin(), new CssMinimizerPlugin()],
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: /node_modules/,
        loader: 'babel-loader',
        options: {
          presets: ['@babel/env']
        },
      },
      {
        test: /\.scss$/,
        exclude: /node_modules/,
        use: [
          {
            loader: MiniCssExtractPlugin.loader,
            options: {
              publicPath: '../',
            },
          },
          {
            loader: 'css-loader',
            options: {
              url: false
            }
          },
          'sass-loader',
        ]
      }
    ]
  },
  plugins: [
    new MiniCssExtractPlugin({
      // Options similar to the same options in webpackOptions.output
      // all options are optional
      filename: 'style.css',
      chunkFilename: '[name].css',
      ignoreOrder: false, // Enable to remove warnings about conflicting order
    }),
    new LiveReloadPlugin(),
    new webpack.ProvidePlugin({
      // $: 'jquery',
      // jQuery: 'jquery',
      // 'window.jQuery': 'jquery',
      Popper: ['popper.js', 'default'],
    })
  ],
  resolve: {
    modules: [sourcePath, 'node_modules'],
    alias: {
      "TweenLite": path.resolve('node_modules', 'gsap/src/uncompressed/TweenLite.js'),
      "TweenMax": path.resolve('node_modules', 'gsap/src/uncompressed/TweenMax.js'),
      "TimelineLite": path.resolve('node_modules', 'gsap/src/uncompressed/TimelineLite.js'),
      "TimelineMax": path.resolve('node_modules', 'gsap/src/uncompressed/TimelineMax.js'),
      "ScrollMagic": path.resolve('node_modules', 'scrollmagic/scrollmagic/uncompressed/ScrollMagic.js'),
      "animation.gsap": path.resolve('node_modules', 'scrollmagic/scrollmagic/uncompressed/plugins/animation.gsap.js'),
      "debug.addIndicators": path.resolve('node_modules', 'scrollmagic/scrollmagic/uncompressed/plugins/debug.addIndicators.js')
    }
  },
}